import * as cloudfront from '@aws-cdk/aws-cloudfront';
import * as cdk from '@aws-cdk/core';
/**
 * @experimental
 */
export interface SimpleWebsiteConfiguration {
    /**
     * (experimental) Local path to the website folder you want to deploy on S3.
     *
     * @experimental
     */
    readonly websiteFolder: string;
    /**
     * (experimental) The index document of the website.
     *
     * @experimental
     */
    readonly indexDoc: string;
    /**
     * (experimental) The error document of the website.
     *
     * @experimental
     */
    readonly errorDoc?: string;
    /**
     * (experimental) Hosted Zone used to create the DNS record for the website.
     *
     * @experimental
     */
    readonly hostedZoneDomain: string;
    /**
     * (experimental) The domain names you want to deploy.
     *
     * @experimental
     */
    readonly websiteDomain: string;
    /**
     * (experimental) The sub-domain name you want to deploy.
     *
     * Default value for a basic website is www
     *
     * @experimental
     */
    readonly websiteSubDomain?: string;
    /**
     * (experimental) The price class determines how many edge locations CloudFront will use for your distribution.
     *
     * Default value is PriceClass_100.
     * See https://aws.amazon.com/cloudfront/pricing/ for full list of supported regions.
     *
     * @experimental
     */
    readonly priceClass?: cloudfront.PriceClass;
}
/**
 * @experimental
 */
export declare class CreateBasicSite extends cdk.Construct {
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: SimpleWebsiteConfiguration);
}
/**
 * @experimental
 */
export declare class CreateCloudfrontSite extends cdk.Construct {
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: SimpleWebsiteConfiguration);
}
